function plugindef()
   finaleplugin.RequireSelection = true
   finaleplugin.MinFinaleVersion = "2025"
   finaleplugin.Author = "Harald Schollmeyer"
   finaleplugin.Version = "1.0"
   finaleplugin.Date = "6.8.2019"
   finaleplugin.AuthorEmail = "hschollm@gmx.net"
   finaleplugin.CategoryTags = "Measure, Region, Smartshape"
   return "Slur Phrases", "Slur Phrases", "Adds slurs over phrases within the selection"
end

-- function to create and assign an entry-attached slur
function MakeSlur( StartEntry, EndEntry)
    -- check for non-zero and non-identical values
    if StartEntry and EndEntry and (StartEntry ~= EndEntry) then

        local smartshape = finale.FCSmartShape()
        smartshape.ShapeType = finale.SMARTSHAPE_SLURAUTO
        smartshape.EntryBased = true
        smartshape.BeatAttached= false
        smartshape.MakeHorizontal = false
        smartshape.PresetShape = true
        smartshape.Visible = true
        smartshape:SetSlurFlags( true )

        local leftseg = smartshape:GetTerminateSegmentLeft()
        leftseg.Measure = StartEntry.Measure
        leftseg.Staff = StartEntry.Staff
        leftseg:SetEntry(StartEntry)

        local rightseg = smartshape:GetTerminateSegmentRight()
        rightseg.Measure = EndEntry.Measure
        rightseg.Staff = EndEntry.Staff
        rightseg:SetEntry(EndEntry)

        smartshape:SaveNewEverything( StartEntry,EndEntry )
     end
end

-- ====================
--    main program starts here
-- ====================

-- we save the selected region
local musicregion = finenv.Region()

-- loop over all staves in the selection
for staff = finenv.Region().StartStaff, finenv.Region().EndStaff do
    -- the working region becomes a single staff of the selection
    musicregion.StartStaff = staff
    musicregion.EndStaff = staff

    -- initalize indexes for start and end entries of a slur:
    local FirstEntry, LastEntry = nil, nil

    -- search for phrases (=note entries seperated by rests) in the current staff
    for noteentry in eachentry(musicregion) do
        -- if we haven't already found a start entry and if the current entry isn't a rest and if it isn't tied backwards: there it is
        if not FirstEntry and not noteentry:IsRest() and not noteentry:IsTiedBackwards() then FirstEntry = noteentry end
        -- the end entry is always the current entry if it's no rest
        if not noteentry:IsRest() then LastEntry = noteentry end

        -- if a rest is found, try to slur the phrase (function will validate values). Reset always indexes.
        if noteentry:IsRest() then
            MakeSlur( FirstEntry, LastEntry)
            FirstEntry, LastEntry = nil, nil
        end
    end

    -- the loop has run out. Try to slur the whole staff (function will validate values)
    MakeSlur( FirstEntry, LastEntry)
end
